@@ -9,10 +9,6 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
  */
 #ifndef SIMTRACE_RINGBUF_H
 #define SIMTRACE_RINGBUF_H
@@ -36,4 +32,22 @@ int rbuf_write(volatile ringbuf * rb, uint8_t item);
 bool rbuf_is_empty(volatile ringbuf * rb);
 bool rbuf_is_full(volatile ringbuf * rb);
 
+
+/* same as above but with 16bit values instead of 8bit */
+
+#define RING16_BUFLEN 512
+
+typedef struct ringbuf16 {
+	uint16_t buf[RING16_BUFLEN];
+	size_t ird;
+	size_t iwr;
+} ringbuf16;
+
+void rbuf16_reset(volatile ringbuf16 * rb);
+uint16_t rbuf16_read(volatile ringbuf16 * rb);
+uint16_t rbuf16_peek(volatile ringbuf16 * rb);
+int rbuf16_write(volatile ringbuf16 * rb, uint16_t item);
+bool rbuf16_is_empty(volatile ringbuf16 * rb);
+bool rbuf16_is_full(volatile ringbuf16 * rb);
+
 #endif /* end of include guard: SIMTRACE_RINGBUF_H */
